@@ -1,5 +1,6 @@
-from pyfk.config.config import SourceModel, SeisModel, Config
+from pyfk.config.config import Config, SeisModel, SourceModel
 from pyfk.gf.gf import calculate_gf
+from pyfk.gf.waveform_integration import mpi_info
 from pyfk.sync.sync import calculate_sync, generate_source_time_function
 
 __all__ = [
@@ -8,6 +9,7 @@ __all__ = [
     "Config",
     "calculate_gf",
     "calculate_sync",
-    "generate_source_time_function"]
+    "generate_source_time_function",
+    "mpi_info"]
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
